import unittest
from molecule_schema import Table
from molecule_schema.predefined import Bytes, BytesOpt


class WitnessArgs(Table):
    molecule_types: BytesOpt()
    molecule_types: BytesOpt()
    molecule_types: BytesOpt()


class TestStringMethods(unittest.TestCase):
    def test_pack_default_witness_args(self):
        bytes = WitnessArgs().pack()
        self.assertEqual(bytes.hex(), "10000000100000001000000010000000")


if __name__ == "__main__":
    unittest.main()



import os
import io
from setuptools import setup, find_packages

HERE = os.path.dirname(os.path.realpath(__file__))

README = os.path.join(HERE, "README.md")
with io.open(README, encoding="utf-8") as f:
    long_description = f.read()

VERSION = os.path.join(HERE, "molecule_schema", "version.py")
with io.open(VERSION, encoding="utf-8") as f:
    package = {}
    exec(f.read(), package)
    version = package["VERSION"]

setup(
    name="molecule-schema",
    version=version,
    description="Molecule Code First Schema",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/doitian/molecule-schema-python",
    author="ian",
    author_email="ian@nervos.org",
    license="MIT",
    packages=find_packages(),
    install_requires=[],
    scripts=[],
    zip_safe=False,
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Environment :: Console",
        "Topic :: File Formats",
    ],
    include_package_data=True,
)
